<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Msl
 * @subpackage Vpc_Msl/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Msl
 * @subpackage Vpc_Msl/admin
 * @author     Orion Origin <freelance@orionorigin.com>
 */
class Vpc_Msl_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Msl_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Msl_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Runs the new version check and upgrade process
	 *
	 * @return \Vpc_Msl_Updater
	 */
	public function get_updater() {
		if ( class_exists( 'vpc' ) ) {
			do_action( 'vpc_before_init_updater' );
			require_once VPC_MSL_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-msl-updater.php';
			$updater = new Vpc_Msl_Updater();
			$updater->init();
			require_once VPC_MSL_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-msl-updating-manager.php';
			$updater->set_update_manager( new Vpc_Msl_Updating_Manager( VPC_MSL_VERSION, $updater->version_url(), VPC_MSL_MAIN_FILE ) );
			do_action( 'vpc_after_init_updater' );
			return $updater;
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Msl_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Msl_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Add Modern skin.
	 *
	 * @param array $skins The default skins array.
	 * @return type array
	 */
	public function vpc_new_skin( $skins ) {
		$skins['VPC_Modern_Skin']               = 'Modern Left Sidebar';
		$skins['VPC_Modern_Skin_Right_Sidebar'] = 'Modern Right Sidebar';
		return $skins;
	}

	/**
	 * Add skin global settings.
	 *
	 * @param array $global_settings The global settings.
	 * @return type
	 */
	public function add_global_settings( $global_settings ) {
		$begin = array(
			'type'  => 'sectionbegin',
			'id'    => 'vpc-msl-container',
			'table' => 'options',
		);

		$end = array( 'type' => 'sectionend' );

		$license_key     = array(
			'title'   => __( 'Modern skin license key', 'vpc-msl' ),
			'name'    => 'vpc-options[purchase-code-modern-skin]',
			'type'    => 'text',
			'desc'    => __( 'This is the license key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://This is the license key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://orionorigin.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?', 'vpc' ),
			'default' => '',
		);
		$msl_icon_width  = array(
			'title'   => __( 'Modern skin icon width', 'vpc-msl' ),
			'name'    => 'vpc-options[msl-icon-width]',
			'type'    => 'number',
			'default' => 40,
		);
		$msl_icon_height = array(
			'title'   => __( 'Modern skin icon height', 'vpc-msl' ),
			'name'    => 'vpc-options[msl-icon-height]',
			'type'    => 'number',
			'default' => 40,
		);
		$msl_icons_size  = array(
			'title'   => __( 'Modern skin icons size', 'vpc-msl' ),
			'name'    => 'vpc-options[msl-options-size]',
			'type'    => 'groupedfields',
			'fields'  => array( $msl_icon_width, $msl_icon_height ),
			'default' => '',
			'desc'    => __( 'Set Modern skin icons size.', 'vpc-msl' ),
		);

		array_push( $global_settings, $begin );
		array_push( $global_settings, $license_key );
		array_push( $global_settings, $msl_icons_size );
		array_push( $global_settings, $end );
		return $global_settings;
	}

}
