<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Msl
 * @subpackage Vpc_Msl/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Vpc_Msl
 * @subpackage Vpc_Msl/public
 * @author     Orion Origin <freelance@orionorigin.com>
 */
class Vpc_Msl_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Msl_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Msl_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( 'vpc-msl-public-css', plugin_dir_url( __FILE__ ) . 'css/vpc-msl-public.css', array(), VPC_MSL_VERSION, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Msl_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Msl_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( 'vpc-msl-public-js', plugin_dir_url( __FILE__ ) . 'js/vpc-msl-public.js', array( 'jquery' ), VPC_MSL_VERSION, false );
	}

	/**
	 * Function to get the text option content.
	 *
	 * @param string  $content             Text output display.
	 * @param array   $option              An option's datas.
	 * @param array   $text_component_data A text component's datas.
	 * @param boolean $monogram            A monogram value.
	 * @param array   $datas               All text option settings datas.
	 * @param array   $component           A component's datas.
	 * @param boolean $multi_views         Tells if multiviews is activated or not.
	 * @param string  $key_view            The current view's key.
	 * @param string  $value_view          The current view's value.
	 * @param array   $config               A configuration's datas.
	 * @return array
	 */
	public function vpc_modern_cta( $content, $option, $text_component_data, $monogram, $datas, $component, $multi_views, $key_view, $value_view, $config ) {
		if ( 'VPC_Modern_Skin' === get_proper_value( $config, 'skin' ) || 'VPC_Modern_Skin_Right_Sidebar' === get_proper_value( $config, 'skin' ) ) {
			$fonts = get_proper_value( $datas, 'fonts' );
			$font  = get_proper_value( $datas, 'font' );

			$colors = get_proper_value( $datas, 'colors' );
			$color  = get_proper_value( $datas, 'color' );

			$font_size = get_proper_value( $datas, 'font_size' );

			$use_multiple_lines = get_proper_value( $datas, 'use_multiple_lines' );

			$text_component_id = get_proper_value( $datas, 'text_component_id' );

			$price = get_proper_value( $datas, 'price' );
			if ( class_exists( 'Woocommerce' ) ) {
				$product_id = get_vpc_current_product_id();
				$price      = vpc_apply_taxes_on_price_if_needed( $price, wc_get_product( $product_id ) );
			}
			$tooltip = get_proper_value( $datas, 'tooltip' );

			$opt_max_char = get_proper_value( $datas, 'opt_max_char' );

			$view_to_focus_on = ( isset( $value_view ) && '' !== $value_view ) ? 'data-view-focus=' . sanitize_title( $value_view ) : '';

			$canvas_id = ( isset( $key_view ) && '' !== $key_view ) ? 'data-canvas-id=text_and_upload_panel_' . $key_view : 'data-canvas-id=text_and_upload_panel';

			$class          = get_proper_value( $datas, 'class', '' );
			$text_value     = get_proper_value( $datas, 'text_value', '' );
			$sanitized_name = get_proper_value( $datas, 'sanitized_name' );
			$opt_name       = get_proper_value( $datas, 'opt_name' );
			$field_selector = $sanitized_name . '-field';

			$tooltip = get_proper_value( $datas, 'tooltip' );

			$show_fonts   = get_proper_value( $config, 'show-fonts' );
			$show_colors  = get_proper_value( $config, 'show-colors' );
			$component_id = 'component_' . sanitize_title( str_replace( ' ', '', $component['cname'] ) );
			$component_id = get_proper_value( $component, 'component_id', $component_id );
			$show_colors  = ( isset( $text_component_data[0] ) && isset( $text_component_data[0]['show-colors'] ) ) ? $text_component_data[0]['show-colors'] : 'yes';
			$show_fonts   = ( isset( $text_component_data[0] ) && isset( $text_component_data[0]['show-fonts'] ) ) ? $text_component_data[0]['show-fonts'] : 'yes';
			ob_start();
			if ( $monogram ) {
				$class = 'monogram_text';
			}
			?>
		<div class="textfield" data-oid="<?php echo esc_attr( $option['option_id'] ); ?>" data-cid="<?php echo esc_attr( $component_id ); ?>" >
			<div class="vpc-group-name"><?php echo esc_html( $opt_name ); ?></div>
			<div class="vpc-textfield">
			<div class="textfield-box cta-box">
			<?php
			if ( isset( $use_multiple_lines ) && 'no' === $use_multiple_lines ) {
				?>
				<label><?php esc_html_e( 'Your text', 'vpc-msl' ); ?></label>
				<input id="<?php echo esc_attr( $sanitized_name ); ?>-field"  name="<?php echo esc_attr( $opt_name ); ?>" class="<?php echo esc_attr( $class ); ?>" type="text"  value="<?php echo esc_attr( $text_value ); ?>" maxlength="<?php echo esc_attr( $opt_max_char ); ?>"  <?php echo esc_html( $view_to_focus_on ); ?> <?php echo esc_html( $canvas_id ); ?> data-price='<?php echo esc_attr( $price ); ?>' data-view="<?php echo esc_html( $value_view ); ?>" data-key="<?php echo esc_html( $key_view ); ?>" />
				<?php
			} elseif ( isset( $use_multiple_lines ) && 'yes' === $use_multiple_lines ) {
				?>
				<label><?php esc_html_e( 'Your text', 'vpc-msl' ); ?></label>
				<textarea id="<?php echo esc_html( $sanitized_name ); ?>-field"  name="<?php echo esc_html( $opt_name ); ?>" class="<?php echo esc_html( $class ); ?>" maxlength="<?php echo esc_html( $opt_max_char ); ?>"  <?php echo esc_html( $view_to_focus_on ); ?> <?php echo esc_html( $canvas_id ); ?> data-price="<?php echo esc_html( $price ); ?>" data-view="<?php echo esc_html( $value_view ); ?>" data-key="<?php echo esc_html( $key_view ); ?>" rows="4"><?php echo esc_html( $text_value ); ?></textarea>
				<?php
			}
			?>
			</div>

			<?php
			if ( ! $monogram ) {
				?>
			<div class="fonts-box cta-box">
				<label><?php esc_html_e( 'Fonts', 'vpc-msl' ); ?></label>
								<div class="vpc-font-dropdown">
				<input type="hidden" name="" id="<?php echo esc_html( $sanitized_name ); ?>-font-selector" data-field="<?php echo esc_html( $sanitized_name ); ?>-field" class="font-selector text-element-border">
				<span class="selected-font-field" ></span>
				<ul class="vpc-font-list">
				<?php
				if ( isset( $fonts ) && is_array( $fonts ) ) {
					foreach ( $fonts as $font_value ) {
						$selected = '';
						if ( $font_value === $font ) {
							$selected = 'selected';
						}
						echo '<li data-value="' . esc_html( $font_value ) . '" data-font="' . esc_html( $font_value ) . ',sans-serif" style="font-family: ' . esc_html( $font_value ) . ',sans-serif" class="' . esc_html( $selected ) . '" data-font-selector-id="' . esc_html( $sanitized_name ) . '-font-selector">' . esc_html( $font_value ) . '</li>';
					}
				}
				?>
				</ul>
				</div>
			</div>
					<?php
			}
			?>

			<div class="color-box cta-box">
				<label><?php esc_html_e( 'Colors', 'vpc-msl' ); ?></label>
				<?php
				foreach ( $colors as $key => $color_arr ) {
					?>
				<div class="vpc-single-option-wrap">
				<input id="cta-<?php echo esc_attr( $sanitized_name . '_' . sanitize_title( $color_arr[0] ) ); ?>-color-selector" type="radio" name="<?php echo esc_html( $sanitized_name ); ?>-color-selector" data-field="<?php echo esc_html( $sanitized_name ); ?>-field" 
					<?php
					if ( $color_arr[0] === $color ) {
						echo 'checked';}
					?>
					data-qtip="no">
				<label for="cta-<?php echo esc_attr( $sanitized_name . '_' . sanitize_title( $color_arr[0] ) ); ?>-color-selector" class="vpc-custom-color custom" data-selector="<?php echo esc_attr( $field_selector ); ?>" data-color="<?php echo esc_attr( $color_arr[0] ); ?>" data-name="<?php echo esc_attr( $color_arr[0] ); ?>" data-oriontip="<?php echo esc_attr( $color_arr[0] ); ?>" style="background-color:<?php echo esc_attr( $color_arr[1] ); ?>"></label>
				</div>

					<?php
				}
				?>
			</div>
			<?php do_action( 'vpc_before_text_container_end', $option, $text_component_data, $monogram, $datas, $component, $multi_views, $key_view, $value_view, $config ); ?>
			</div>
		</div>
			<?php
			$content = ob_get_contents();
			ob_end_clean();
			$content = apply_filters( 'vpc_msl_text_container', $content, $option, $text_component_data, $monogram, $datas, $component, $multi_views, $key_view, $value_view, $config );
		}
		return $content;
	}

	/**
	 * Function to get Sfla configuration datas.
	 *
	 * @param string $content The sfla output.
	 * @param array  $config   configuration datas.
	 * @param int    $prod_id  Product id.
	 */
	public function vpc_modern_sfla( $content, $config, $prod_id ) {
		if ( 'VPC_Modern_Skin' === get_proper_value( $config, 'skin' ) || 'VPC_Modern_Skin_Right_Sidebar' === get_proper_value( $config, 'skin' ) ) {
			ob_start();
			$content = '';
			$metas   = get_user_meta( get_current_user_id(), 'user_configs', true );
			if ( ( is_array( $metas ) ) && ( count( $metas ) > 0 ) ) {
				$saved_configs_per_product = vpc_sfla_get_saved_config_per_product( $metas );
				if ( ! empty( $saved_configs_per_product ) ) {
					foreach ( $saved_configs_per_product as $prod_id => $configs_data ) {
						?>
						<div class='msl_sfl_product_name'><?php echo esc_html( get_the_title( $prod_id ) ); ?></div> 
						<?php
						$this->saved_configs_output_per_product( $configs_data );
					}
				}
			}
			$content = ob_get_contents();
			ob_end_clean();
		}
		return wp_kses_post( $content );
	}

	/**
	 * Function to render show saved configurations per product.
	 *
	 * @param array $configs_data Saved configurations datas per product.
	 */
	public function saved_configs_output_per_product( $configs_data ) {
		if ( isset( $configs_data ) && ! empty( $configs_data ) ) {
			foreach ( $configs_data as $config ) {
				?>
		<div class="msl_sfl_bloc">
			<div class="msl_sfl_image">
			<img src="<?php echo esc_attr( $config['config_img'] ); ?>">
			<span><?php echo esc_html( $config['config_name'] ); ?></span>
			</div>
			<div class="msl_sfl_buttons">
			<a class="save_later" href="<?php echo esc_url( $config['edit_url'] ); ?>"><?php esc_html_e( 'Load', 'vpc-msl' ); ?></a>
			<a class="delete_saved" href="#" data-id="<?php echo esc_attr( $config['meta_id'] ); ?>"><?php esc_html_e( 'Delete', 'vpc-msl' ); ?></a>
			</div>
		</div>
				<?php
			}
		}
	}

	/**
	 * Add new body class.
	 *
	 * @param array $classes Condifurator body class.
	 */
	public function vpc_modern_body_class( $classes ) {
		$classes[] = 'vpc-modern-configurator';
		return $classes;
	}

	/**
	 * Function to get Sfla configuration.
	 *
	 * @param array $config   configuration datas.
	 * @param int   $prod_id  Product id.
	 */
	public static function msl_get_saved_configs( $config, $prod_id ) {
		ob_start();
		$content = '';
		if ( is_user_logged_in() && isset( $config['save-for-later'] ) && 'Yes' === $config['save-for-later'] ) {
			if ( ! get_option( 'vpc-save-for-later-add-on-license-key' ) ) {
				echo "<h2 class='error_msg'>You have not activated your license yet. Please, activate it in order to use Save for later addon.</h2>";
			} else {
				$metas = get_user_meta( get_current_user_id(), 'user_configs', true );
				if ( ( is_array( $metas ) ) && ( count( $metas ) > 0 ) ) {
					$saved_configs_per_product = vpc_sfla_get_saved_config_per_product( $metas );
					if ( ! empty( $saved_configs_per_product ) ) {
						if ( isset( $saved_configs_per_product[ $prod_id ] ) && ! empty( $saved_configs_per_product[ $prod_id ] ) ) {
							foreach ( $saved_configs_per_product[ $prod_id ] as $config ) {
								?>
				<div class="msl_sfl_bloc">
					<div class="msl_sfl_image">
					<img src="<?php echo esc_attr( $config['config_img'] ); ?>">
					<span><?php echo esc_html( $config['config_name'] ); ?></span>
					</div>
					<div class="msl_sfl_buttons">
					<a class="save_later" href="<?php echo esc_url( $config['edit_url'] ); ?>"><?php esc_html_e( 'Load', 'vpc-msl' ); ?></a>
					<a class="delete_saved" href="#" data-id="<?php echo esc_attr( $config['meta_id'] ); ?>"><?php esc_html_e( 'Delete', 'vpc-msl' ); ?></a>
					</div>
				</div>
								<?php
							}
						}
					}
				}
			}
		}
		$content = ob_get_contents();
		ob_end_clean();
		$content = apply_filters( 'vpc_sfla.config_saved_content', $content, $config, $prod_id ); // phpcs:ignore
		echo wp_kses_post( $content );
	}

}
